Bibliography
============

.. Comment: 
   needs to be the alphabetically last file in the directory:
   https://github.com/mcmtroffaes/sphinxcontrib-bibtex/issues/8

.. bibliography:: references.bib
   :cited:
   :style: alpha